@@ -1,4 +1,4 @@
-partial.resid.plot <- function (x, smooth.span = 0.8) 
+partial.resid.plot <- function (x, smooth.span = 0.8, lf.col = 2, sm.col = 4,...) 
 {
     p <- ncol(x$model)
     X <- as.matrix(x$model[,2:p])
@@ -13,12 +13,12 @@ partial.resid.plot <- function (x, smooth.span = 0.8)
         plot(other.resid[, i], resid[, i], xlab = bquote(paste(hat(epsilon), 
             "(", .(colnames(X)[i]), " | model without ", .(colnames(X)[i]), 
             ")")), ylab = bquote(paste(hat(epsilon), "(Y | model without ", 
-            .(colnames(X)[i]), ")")))
+            .(colnames(X)[i]), ")")),...)
         l1 <- lm(resid[, i] ~ other.resid[, i])
         abline(as.numeric(l1$coefficients[1]), as.numeric(l1$coefficients[2]), 
-            col = 2, lty = 1)
+            col = lf.col, lty = 1)
         lines(lowess(other.resid[, i], resid[, i], f = smooth.span), 
-            lty = 2, col = 4)
+            lty = 2, col = sm.col)
         readline("Press return for next plot")
     }
 }
\ No newline at end of file
